@@ -1,7 +1,7 @@
 package Net::DNS::Packet;
-
-# $Id: Packet.pm,v 1.19 2003/08/04 03:41:52 ctriv Exp $
-
+#
+# $Id: Packet.pm,v 1.22 2003/09/03 04:41:50 ctriv Exp $
+#
 use strict;
 use vars qw(@ISA @EXPORT_OK $VERSION $AUTOLOAD);
 
@@ -14,7 +14,7 @@ use Net::DNS;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-$VERSION = $Net::DNS::VERSION;
+$VERSION = (qw$Revision: 1.22 $)[1];
 
 =head1 NAME
 
@@ -833,7 +833,12 @@ sub sign_sig0 {
     
     if (@_ == 1 && ref($_[0])) {
 	if (UNIVERSAL::isa($_[0],"Net::DNS::RR::SIG::Private")){
+	    Carp::carp ('Net::DNS::RR::SIG::Private is deprecated use Net::DNS::SEC::Private instead');
 	    $sig0 = Net::DNS::RR::SIG->create('', $_[0]) if $_[0];
+
+	}elsif (UNIVERSAL::isa($_[0],"Net::DNS::SEC::Private")){
+	    $sig0 = Net::DNS::RR::SIG->create('', $_[0]) if $_[0];
+
 	}elsif (UNIVERSAL::isa($_[0],"Net::DNS::RR::SIG")){
 	    $sig0 = $_[0];
 	}else{
@@ -945,10 +950,12 @@ sub parse_rr {
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr.  All rights reserved.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
 
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 DNSSEC/EDNS0 functionality courtesy of Olaf M. Kolkman, RIPE NCC.  
 
