@@ -1,14 +1,15 @@
 package Net::DNS::RR::AFSDB;
-
-# $Id: AFSDB.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: AFSDB.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS;
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.5 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -57,6 +58,20 @@ sub rr_rdata {
 	return $rdata;
 }
 
+
+
+sub _canonicalRdata {
+    # rdata contains a compressed domainname... we should not have that.
+	my ($self) = @_;
+	my $rdata;
+	if (exists $self->{"subtype"}) {
+	    $rdata .= pack("n", $self->{"subtype"});
+	    $rdata .=  $self->_name2wire($self->{"hostname"});
+	}
+	return $rdata;
+}
+
+
 1;
 __END__
 
@@ -89,9 +104,12 @@ Returns the RR's hostname field.  See RFC 1183.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
