@@ -1,13 +1,14 @@
 package Net::DNS::RR::ISDN;
-
-# $Id: ISDN.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: ISDN.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.5 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -40,9 +41,9 @@ sub new {
 sub new_from_string {
 	my ($class, $self, $string) = @_;
 
-	if ($string && $string =~ /^['"](.*?)['"]/) {
+	if ($string && $string =~ /^['"](.*?)['"](.*)/s) {
 		$self->{"address"} = $1;
-		my $rest = $';
+		my $rest = $2;
 
 		if ($rest =~ /^\s+['"](.*?)['"]$/) {
 			$self->{"sa"} = $1;
@@ -111,9 +112,12 @@ Returns the RR's subaddress field.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
